Skip to contents

Returns the unique methylation modification types stored in a commaData object.

Usage

modTypes(object)

# S4 method for class 'commaData'
modTypes(object)

Arguments

object

A commaData object.

Value

A character vector of modification types present in rowData(object)$mod_type (e.g., c("6mA", "5mC")).

Examples

data(comma_example_data)
modTypes(comma_example_data)
#> [1] "5mC" "6mA"